a table of cancer rate data by country, retrieved from https://gco.iarc.fr/today/online-analysis-map
Source:R/data.R
world_cancer_2020_all.Rda table of cancer rate data by country, retrieved from https://gco.iarc.fr/today/online-analysis-map
Usage
data(world_cancer_2020_all)